==> ejc-accplat-impl-3.0.0-20240102.014812-61-sources.jar: com/ejianc/business/accplat/originvoucher/bean/VoucherTemplateDetailEntity.java <==
package com.ejianc.business.accplat.originvoucher.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 凭证模板明细
 *
 * @author generator
 *
 */
@TableName("ejc_accplat_voucher_template_detail")
public class VoucherTemplateDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "voucher_template_id")
    private Long voucherTemplateId; // 模版ID
    @TableField(value = "condition_expression")
    private String conditionExpression; // 条件公式
    @TableField(value = "condition_expression_view")
    private String conditionExpressionView; // 条件公式显示名称
    @TableField(value = "description_expression")
    private String descriptionExpression; // 摘要表达式
    @TableField(value = "description_expression_view")
    private String descriptionExpressionView; // 摘要表达式显示名称
    @TableField(value = "subject_rule_flag")
    private String subjectRuleFlag; // 科目规则subject固定科目subjectContrast科目分类转化
    @TableField(value = "subject_rule_id")
    private Long subjectRuleId; // 科目规则-ID科目id或科目分类id
    @TableField(value = "subject_rule_code")
    private String subjectRuleCode; // 科目规则编码-科目编码或科目分类编码
    @TableField(value = "subject_rule_name")
    private String subjectRuleName; // 科目规则名称-科目名称或科目分类名称
    @TableField(value = "direction_flag")
    private String directionFlag; // 借贷方向debit借crebit贷
    @TableField(value = "mny_expression")
    private String mnyExpression; // 金额取值规则
    @TableField(value = "mny_expression_view")
    private String mnyExpressionView; // 金额取值规则显示名称


    public Long getVoucherTemplateId() {
        return voucherTemplateId;
    }

    public void setVoucherTemplateId(Long voucherTemplateId) {
        this.voucherTemplateId = voucherTemplateId;
    }

    public String getConditionExpression() {
        return conditionExpression;
    }

    public void setConditionExpression(String conditionExpression) {
        this.conditionExpression = conditionExpression;
    }

    public String getConditionExpressionView() {
        return conditionExpressionView;
    }

    public void setConditionExpressionView(String conditionExpressionView) {
        this.conditionExpressionView = conditionExpressionView;
    }

    public String getDescriptionExpression() {
        return descriptionExpression;
    }

    public void setDescriptionExpression(String descriptionExpression) {
        this.descriptionExpression = descriptionExpression;
    }

    public String getDescriptionExpressionView() {
        return descriptionExpressionView;
    }

    public void setDescriptionExpressionView(String descriptionExpressionView) {
        this.descriptionExpressionView = descriptionExpressionView;
    }

    public String getSubjectRuleFlag() {
        return subjectRuleFlag;
    }

    public void setSubjectRuleFlag(String subjectRuleFlag) {
        this.subjectRuleFlag = subjectRuleFlag;
    }

    public Long getSubjectRuleId() {
        return subjectRuleId;
    }

    public void setSubjectRuleId(Long subjectRuleId) {
        this.subjectRuleId = subjectRuleId;
    }

    public String getSubjectRuleCode() {
        return subjectRuleCode;
    }

    public void setSubjectRuleCode(String subjectRuleCode) {
        this.subjectRuleCode = subjectRuleCode;
    }

    public String getSubjectRuleName() {
        return subjectRuleName;
    }

    public void setSubjectRuleName(String subjectRuleName) {
        this.subjectRuleName = subjectRuleName;
    }

    public String getDirectionFlag() {
        return directionFlag;
    }

    public void setDirectionFlag(String directionFlag) {
        this.directionFlag = directionFlag;
    }

    public String getMnyExpression() {
        return mnyExpression;
    }

    public void setMnyExpression(String mnyExpression) {
        this.mnyExpression = mnyExpression;
    }

    public String getMnyExpressionView() {
        return mnyExpressionView;
    }

    public void setMnyExpressionView(String mnyExpressionView) {
        this.mnyExpressionView = mnyExpressionView;
    }

}

==> ejc-accplat-impl-3.0.0-20240124.025510-141-sources.jar: com/ejianc/business/accplat/originvoucher/bean/VoucherTemplateDetailEntity.java <==
package com.ejianc.business.accplat.originvoucher.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 凭证模板明细
 *
 * @author generator
 *
 */
@TableName("ejc_accplat_voucher_template_detail")
public class VoucherTemplateDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "voucher_template_id")
    private Long voucherTemplateId; // 模版ID
    @TableField(value = "condition_expression")
    private String conditionExpression; // 条件公式
    @TableField(value = "condition_expression_view")
    private String conditionExpressionView; // 条件公式显示名称
    @TableField(value = "description_flag")
    private String descriptionFlag; // 摘要标识input录入referUse常用billColumn单据字段
    @TableField(value = "description_expression")
    private String descriptionExpression; // 摘要表达式
    @TableField(value = "description_expression_view")
    private String descriptionExpressionView; // 摘要表达式显示名称
    @TableField(value = "subject_rule_flag")
    private String subjectRuleFlag; // 科目规则subject固定科目subjectContrast科目分类转化
    @TableField(value = "subject_rule_id")
    private Long subjectRuleId; // 科目规则-ID科目id或科目分类id
    @TableField(value = "subject_rule_code")
    private String subjectRuleCode; // 科目规则编码-科目编码或科目分类编码
    @TableField(value = "subject_rule_name")
    private String subjectRuleName; // 科目规则名称-科目名称或科目分类名称
    @TableField(value = "direction_flag")
    private String directionFlag; // 借贷方向debit借credit贷
    @TableField(value = "mny_expression")
    private String mnyExpression; // 金额取值规则
    @TableField(value = "mny_expression_view")
    private String mnyExpressionView; // 金额取值规则显示名称

    public String getDescriptionFlag() {
        return descriptionFlag;
    }

    public void setDescriptionFlag(String descriptionFlag) {
        this.descriptionFlag = descriptionFlag;
    }

    public Long getVoucherTemplateId() {
        return voucherTemplateId;
    }

    public void setVoucherTemplateId(Long voucherTemplateId) {
        this.voucherTemplateId = voucherTemplateId;
    }

    public String getConditionExpression() {
        return conditionExpression;
    }

    public void setConditionExpression(String conditionExpression) {
        this.conditionExpression = conditionExpression;
    }

    public String getConditionExpressionView() {
        return conditionExpressionView;
    }

    public void setConditionExpressionView(String conditionExpressionView) {
        this.conditionExpressionView = conditionExpressionView;
    }

    public String getDescriptionExpression() {
        return descriptionExpression;
    }

    public void setDescriptionExpression(String descriptionExpression) {
        this.descriptionExpression = descriptionExpression;
    }

    public String getDescriptionExpressionView() {
        return descriptionExpressionView;
    }

    public void setDescriptionExpressionView(String descriptionExpressionView) {
        this.descriptionExpressionView = descriptionExpressionView;
    }

    public String getSubjectRuleFlag() {
        return subjectRuleFlag;
    }

    public void setSubjectRuleFlag(String subjectRuleFlag) {
        this.subjectRuleFlag = subjectRuleFlag;
    }

    public Long getSubjectRuleId() {
        return subjectRuleId;
    }

    public void setSubjectRuleId(Long subjectRuleId) {
        this.subjectRuleId = subjectRuleId;
    }

    public String getSubjectRuleCode() {
        return subjectRuleCode;
    }

    public void setSubjectRuleCode(String subjectRuleCode) {
        this.subjectRuleCode = subjectRuleCode;
    }

    public String getSubjectRuleName() {
        return subjectRuleName;
    }

    public void setSubjectRuleName(String subjectRuleName) {
        this.subjectRuleName = subjectRuleName;
    }

    public String getDirectionFlag() {
        return directionFlag;
    }

    public void setDirectionFlag(String directionFlag) {
        this.directionFlag = directionFlag;
    }

    public String getMnyExpression() {
        return mnyExpression;
    }

    public void setMnyExpression(String mnyExpression) {
        this.mnyExpression = mnyExpression;
    }

    public String getMnyExpressionView() {
        return mnyExpressionView;
    }

    public void setMnyExpressionView(String mnyExpressionView) {
        this.mnyExpressionView = mnyExpressionView;
    }

}
